@@ -4,7 +4,7 @@ use warnings;
 use 5.006;
 
 package LWP::ConsoleLogger;
-$LWP::ConsoleLogger::VERSION = '0.000018';
+$LWP::ConsoleLogger::VERSION = '0.000019';
 use Data::Printer { end_separator => 1, hash_separator => ' => ' };
 use DateTime qw();
 use HTML::Restrict qw();
@@ -349,13 +349,13 @@ sub _parse_body {
     elsif ( lc $subtype eq 'xml' ) {
         try {
             my $pretty = XMLin( $content, KeepRoot => 1 );
-            $content = p($pretty);
+            $content = p( $pretty, return_value => 'dump' );
         }
         catch { $t->row("Error parsing XML: $_") };
     }
     elsif ( lc $subtype eq 'json' ) {
         try {
-            $content = p( decode_json($content) );
+            $content = p( decode_json($content), return_value => 'dump' );
         }
         catch { $t->row("Error parsing JSON: $_") };
     }
@@ -405,7 +405,7 @@ LWP::ConsoleLogger - LWP tracing and debugging
 
 =head1 VERSION
 
-version 0.000018
+version 0.000019
 
 =head1 SYNOPSIS
 
